require 'test_helper'

class OcacheBenchmarkTest < ActiveSupport::TestCase
  setup do
    Rails.cache.write('init', true)
    Rails.cache.clear
    puts "\n"
  end

  def teardown
    setup
  end

  test 'rails.cache vs cache_fetch' do
    Benchmark.bmbm(100) do |x|
      x.report('rails.cache') {
        for i in 1..1_000
          Rails.cache.fetch('queryables/expensive_class_method') do
            Vote.expensive_class_method
          end
        end
      }

      Rails.cache.clear
      x.report('cache_fetch')  {
        for i in 1..1_000
          Vote.cache_fetch.expensive_class_method
        end
      }

      Rails.cache.clear
      x.report('rails.cache w/ force') {
        for i in 1..1_000
          Rails.cache.fetch('queryables/expensive_class_method', force: true) do
            Vote.expensive_class_method
          end
        end
      }

      Rails.cache.clear
      x.report('cache_fetch w/ force')  {
        for i in 1..1_000
          Vote.cache_fetch(force: true).expensive_class_method
        end
      }

      Rails.cache.clear
      x.report('rails.cache w/ options') {
        for i in 1..1_000
          Rails.cache.fetch('queryables/expensive_class_method', expires_in: 4.years) do
            Vote.expensive_class_method
          end
        end
      }

      Rails.cache.clear
      x.report('cache_fetch w/ options')  {
        for i in 1..1_000
          Vote.cache_fetch(expires_in: 4.years).expensive_class_method
        end
      }
    end
  end
end
